# Note: Distances are approximations. The distances of these globular clusters are not 
# known to more precision than the distance to the galaxy itself. So, some random
# variation has been added. This means that the CoreRadius and AbsMag parameters have some
# variation as well, since the calculation for it depends on the distance.
#
# The CoreRadius and KingConcentration parameters have been taken from various papers.
# Since the KingConcentration is the logarithm of the ratio between the tidal and core
# radius, if one has two of the parameters, the third parameter can be calculated.
# However, many of the parameters are still likely complete estimates.
# 
# Sources are listed here, in order of decreasing preference:
# Structural Parameters of Mayall II = G1 in M31
# http://adsabs.harvard.edu/abs/2007MNRAS.376.1621M
# 
# Structural Parameters for Globular Clusters in M31
# http://adsabs.harvard.edu/abs/2013AJ....146...20W
# 
# A Comparison Between the Half-light Radii, Luminosities, and UBV Colors of Globular 
# Clusters in M31 and the Galaxy
# http://adsabs.harvard.edu/abs/2010AJ....140.1043V
# 
# The M31 globular cluster system: ugriz and K-band photometry and structural parameters
# http://adsabs.harvard.edu/abs/2010MNRAS.402..803P
#
# A Hubble Space Telescope/WFPC2 Survey of Bright Young Clusters in M31. III. Structural 
# Parameters
# http://adsabs.harvard.edu/abs/2009AJ....138.1667B
# 
# A Survey of Compact Star Clusters in the S-W Field of the M 31 Disk. Structural 
# Parameters. II
# http://adsabs.harvard.edu/abs/2007BaltA..16..397S
# 
# A Survey of Compact Star Clusters in the South-West Field of the M 31 Disk. Structural 
# Parameters
# http://adsabs.harvard.edu/abs/2006BaltA..15..547S
# 
# M31 Globular Clusters in the Hubble Space Telescope Archive. II. Structural Parameters
# http://adsabs.harvard.edu/abs/2002AJ....123.1937B

Globular "Mayall II:SKHB 1"
{
	RA          	  0.546258  # [hours]
	Dec         	 39.577917  # [degrees]
	Distance    	 2.511e+06  # [ly]
	Radius      	     10.34  # [ly]
	CoreRadius  	    0.0035  # [arcmin]
	KingConcentration     2.01  # c = log10(r_t/r_c)
	AbsMag      	   -10.625  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NAME+Mayall+II"
}

Globular "Bol 292:SKHB 10"
{
	RA          	  0.604628  # [hours]
	Dec         	  40.97403  # [degrees]
	Distance    	2.5498e+06  # [ly]
	Radius      	     103.7  # [ly]
	CoreRadius  	     0.005  # [arcmin]
	KingConcentration     1.45  # c = log10(r_t/r_c)
	AbsMag      	     -7.47  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+292"
}

Globular "RX J0036.3+4053:Bol 293:SKHB 11"
{
	RA          	  0.605795  # [hours]
	Dec         	  40.89364  # [degrees]
	Distance    	2.5546e+06  # [ly]
	Radius      	     128.5  # [ly]
	CoreRadius  	    0.0047  # [arcmin]
	KingConcentration     1.57  # c = log10(r_t/r_c)
	AbsMag      	    -8.119  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=RX+J0036.3%2B4053"
}

Globular "BA 3-19:Bol 295:SKHB 14"
{
	RA          	  0.612981  # [hours]
	Dec         	  40.32842  # [degrees]
	Distance    	2.5862e+06  # [ly]
	Radius      	     93.61  # [ly]
	CoreRadius  	    0.0065  # [arcmin]
	KingConcentration     1.28  # c = log10(r_t/r_c)
	AbsMag      	    -7.746  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=BA+3-19"
}

Globular "Bol 298:SKHB 21"
{
	RA          	  0.633403  # [hours]
	Dec         	  40.73222  # [degrees]
	Distance    	2.5521e+06  # [ly]
	Radius      	       105  # [ly]
	CoreRadius  	    0.0041  # [arcmin]
	KingConcentration     1.54  # c = log10(r_t/r_c)
	AbsMag      	    -7.877  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+298"
}

Globular "BA 3-15:Bol 301:SKHB 22"
{
	RA          	  0.639333  # [hours]
	Dec         	  40.06028  # [degrees]
	Distance    	2.5962e+06  # [ly]
	Radius      	     79.58  # [ly]
	CoreRadius  	    0.0053  # [arcmin]
	KingConcentration      1.3  # c = log10(r_t/r_c)
	AbsMag      	    -7.575  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=BA+3-15"
}

Globular "Bol 302:SKHB 23"
{
	RA          	  0.642642  # [hours]
	Dec         	  41.34789  # [degrees]
	Distance    	 2.598e+06  # [ly]
	Radius      	     94.26  # [ly]
	CoreRadius  	    0.0147  # [arcmin]
	KingConcentration     0.93  # c = log10(r_t/r_c)
	AbsMag      	    -7.826  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+302"
}

Globular "Bol 304:SKHB 28"
{
	RA          	   0.64915  # [hours]
	Dec         	  41.17456  # [degrees]
	Distance    	2.5219e+06  # [ly]
	Radius      	     116.8  # [ly]
	CoreRadius  	    0.0054  # [arcmin]
	KingConcentration     1.47  # c = log10(r_t/r_c)
	AbsMag      	    -7.616  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+304"
}

Globular "Bol 305"
{
	RA          	  0.649681  # [hours]
	Dec         	  40.27558  # [degrees]
	Distance    	 2.537e+06  # [ly]
	Radius      	     105.3  # [ly]
	CoreRadius  	    0.0009  # [arcmin]
	KingConcentration     2.18  # c = log10(r_t/r_c)
	AbsMag      	    -6.965  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+305"
}

Globular "BA 3-18:Bol 306:SKHB 29"
{
	RA          	  0.652417  # [hours]
	Dec         	   40.5725  # [degrees]
	Distance    	2.5637e+06  # [ly]
	Radius      	     118.1  # [ly]
	CoreRadius  	    0.0025  # [arcmin]
	KingConcentration      1.8  # c = log10(r_t/r_c)
	AbsMag      	    -8.017  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=BA+3-18"
}

Globular "Bol 307:SKHB 30"
{
	RA          	  0.655125  # [hours]
	Dec         	  40.54947  # [degrees]
	Distance    	 2.577e+06  # [ly]
	Radius      	     171.9  # [ly]
	CoreRadius  	    0.0014  # [arcmin]
	KingConcentration      2.2  # c = log10(r_t/r_c)
	AbsMag      	    -7.168  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+307"
}

Globular "Bol 309:SKHB 31"
{
	RA          	  0.656842  # [hours]
	Dec         	  40.24142  # [degrees]
	Distance    	2.5685e+06  # [ly]
	Radius      	     86.76  # [ly]
	CoreRadius  	    0.0216  # [arcmin]
	KingConcentration     0.73  # c = log10(r_t/r_c)
	AbsMag      	    -7.071  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+309"
}

Globular "Bol 436"
{
	RA          	  0.658517  # [hours]
	Dec         	  40.30569  # [degrees]
	Distance    	2.5436e+06  # [ly]
	Radius      	     111.5  # [ly]
	CoreRadius  	    0.0097  # [arcmin]
	KingConcentration     1.19  # c = log10(r_t/r_c)
	AbsMag      	     -6.26  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+436"
}

Globular "BA 3-17:Bol 311:SKHB 33"
{
	RA          	  0.659367  # [hours]
	Dec         	  40.52075  # [degrees]
	Distance    	2.6174e+06  # [ly]
	Radius      	     104.4  # [ly]
	CoreRadius  	    0.0026  # [arcmin]
	KingConcentration     1.72  # c = log10(r_t/r_c)
	AbsMag      	    -8.962  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=BA+3-17"
}

Globular "Bol 312:SKHB 35"
{
	RA          	  0.661158  # [hours]
	Dec         	  40.95067  # [degrees]
	Distance    	2.6005e+06  # [ly]
	Radius      	     140.6  # [ly]
	CoreRadius  	    0.0047  # [arcmin]
	KingConcentration      1.6  # c = log10(r_t/r_c)
	AbsMag      	    -8.988  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+312"
}

Globular "Bol 316:SKHB 40"
{
	RA          	  0.664886  # [hours]
	Dec         	  40.69417  # [degrees]
	Distance    	2.5715e+06  # [ly]
	Radius      	     192.4  # [ly]
	CoreRadius  	    0.0132  # [arcmin]
	KingConcentration     1.29  # c = log10(r_t/r_c)
	AbsMag      	    -7.424  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+316"
}

Globular "Bol 318:SKHB 42"
{
	RA          	  0.666905  # [hours]
	Dec         	  40.56889  # [degrees]
	Distance    	2.6026e+06  # [ly]
	Radius      	     0.076  # [ly]
	CoreRadius  	    0.0001  # [arcmin]
	KingConcentration    3.581  # c = log10(r_t/r_c)
	AbsMag      	     -7.53  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+318"
}

Globular "Bol 2:SKHB 43"
{
	RA          	  0.667381  # [hours]
	Dec         	  41.19822  # [degrees]
	Distance    	2.5297e+06  # [ly]
	Radius      	     80.89  # [ly]
	CoreRadius  	    0.0015  # [arcmin]
	KingConcentration     1.86  # c = log10(r_t/r_c)
	AbsMag      	    -6.898  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+2"
}

Globular "Bol 3:SKHB 45"
{
	RA          	  0.669278  # [hours]
	Dec         	  41.18478  # [degrees]
	Distance    	2.5164e+06  # [ly]
	Radius      	     139.3  # [ly]
	CoreRadius  	    0.0011  # [arcmin]
	KingConcentration     2.25  # c = log10(r_t/r_c)
	AbsMag      	    -6.867  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+3"
}

Globular "Bol 321:SKHB 46"
{
	RA          	  0.670939  # [hours]
	Dec         	  40.46275  # [degrees]
	Distance    	2.6191e+06  # [ly]
	Radius      	     2.251  # [ly]
	CoreRadius  	     0.003  # [arcmin]
	KingConcentration    2.451  # c = log10(r_t/r_c)
	AbsMag      	    -6.854  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+321"
}

Globular "Bol 4:SKHB 50"
{
	RA          	  0.671641  # [hours]
	Dec         	  41.37786  # [degrees]
	Distance    	2.6225e+06  # [ly]
	Radius      	      69.8  # [ly]
	CoreRadius  	    0.0039  # [arcmin]
	KingConcentration     1.37  # c = log10(r_t/r_c)
	AbsMag      	    -7.576  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+4"
}

Globular "Bol 6:SKHB 58"
{
	RA          	  0.674019  # [hours]
	Dec         	  41.45739  # [degrees]
	Distance    	2.5618e+06  # [ly]
	Radius      	     118.1  # [ly]
	CoreRadius  	    0.0009  # [arcmin]
	KingConcentration     2.26  # c = log10(r_t/r_c)
	AbsMag      	    -8.736  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+6"
}

Globular "Bol 333"
{
	RA          	  0.674897  # [hours]
	Dec         	  41.67383  # [degrees]
	Distance    	2.6225e+06  # [ly]
	Radius      	     238.7  # [ly]
	CoreRadius  	    0.0003  # [arcmin]
	KingConcentration     3.04  # c = log10(r_t/r_c)
	AbsMag      	    -5.686  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+333"
}

Globular "Bol 8:SKHB 60"
{
	RA          	  0.675075  # [hours]
	Dec         	  41.26908  # [degrees]
	Distance    	2.5113e+06  # [ly]
	Radius      	     54.79  # [ly]
	CoreRadius  	    0.0097  # [arcmin]
	KingConcentration     0.89  # c = log10(r_t/r_c)
	AbsMag      	    -7.872  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+8"
}

Globular "Bol 9:SKHB 61"
{
	RA          	  0.675197  # [hours]
	Dec         	  41.61547  # [degrees]
	Distance    	2.5593e+06  # [ly]
	Radius      	     80.23  # [ly]
	CoreRadius  	    0.0025  # [arcmin]
	KingConcentration     1.64  # c = log10(r_t/r_c)
	AbsMag      	    -7.554  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+9"
}

Globular "Bol 10:SKHB 62"
{
	RA          	  0.675436  # [hours]
	Dec         	  41.23956  # [degrees]
	Distance    	2.5806e+06  # [ly]
	Radius      	     157.2  # [ly]
	CoreRadius  	    0.0118  # [arcmin]
	KingConcentration     1.25  # c = log10(r_t/r_c)
	AbsMag      	    -7.831  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+10"
}

Globular "Bol 11:SKHB 63"
{
	RA          	  0.675522  # [hours]
	Dec         	  41.65475  # [degrees]
	Distance    	2.5294e+06  # [ly]
	Radius      	     68.82  # [ly]
	CoreRadius  	    0.0028  # [arcmin]
	KingConcentration     1.52  # c = log10(r_t/r_c)
	AbsMag      	     -7.87  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+11"
}

Globular "Bol 12:SKHB 64"
{
	RA          	  0.675694  # [hours]
	Dec         	 41.362189  # [degrees]
	Distance    	2.5291e+06  # [ly]
	Radius      	     117.7  # [ly]
	CoreRadius  	     0.004  # [arcmin]
	KingConcentration      1.6  # c = log10(r_t/r_c)
	AbsMag      	    -9.278  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+12"
}

Globular "[HTF2008] H16"
{
	RA          	  0.677169  # [hours]
	Dec         	  39.75831  # [degrees]
	Distance    	2.5787e+06  # [ly]
	Radius      	     296.8  # [ly]
	CoreRadius  	     0.025  # [arcmin]
	KingConcentration      1.2  # c = log10(r_t/r_c)
	AbsMag      	     -6.96  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=%5BHTF2008%5D+H16"
}

Globular "[NVK2008] KW125"
{
	RA          	  0.679721  # [hours]
	Dec         	   40.6828  # [degrees]
	Distance    	 2.539e+06  # [ly]
	Radius      	     112.5  # [ly]
	CoreRadius  	    0.0008  # [arcmin]
	KingConcentration     2.26  # c = log10(r_t/r_c)
	AbsMag      	    -5.206  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=%5BNVK2008%5D+KW125"
}

Globular "Bol 336:SKHB 67"
{
	RA          	  0.679892  # [hours]
	Dec         	  42.14503  # [degrees]
	Distance    	2.5706e+06  # [ly]
	Radius      	     38.16  # [ly]
	CoreRadius  	    0.0112  # [arcmin]
	KingConcentration     0.66  # c = log10(r_t/r_c)
	AbsMag      	    -6.672  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+336"
}

Globular "Bol 337:SKHB 68"
{
	RA          	  0.680133  # [hours]
	Dec         	  42.20303  # [degrees]
	Distance    	2.5685e+06  # [ly]
	Radius      	     58.71  # [ly]
	CoreRadius  	    0.0051  # [arcmin]
	KingConcentration     1.19  # c = log10(r_t/r_c)
	AbsMag      	    -7.748  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+337"
}

Globular "Bol 17:SKHB 70"
{
	RA          	  0.680203  # [hours]
	Dec         	  41.20197  # [degrees]
	Distance    	2.5189e+06  # [ly]
	Radius      	     128.5  # [ly]
	CoreRadius  	    0.0032  # [arcmin]
	KingConcentration     1.74  # c = log10(r_t/r_c)
	AbsMag      	    -8.399  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+17"
}

Globular "Bol 19:SKHB 72"
{
	RA          	  0.681258  # [hours]
	Dec         	  41.31483  # [degrees]
	Distance    	2.5683e+06  # [ly]
	Radius      	     110.6  # [ly]
	CoreRadius  	    0.0028  # [arcmin]
	KingConcentration     1.72  # c = log10(r_t/r_c)
	AbsMag      	    -9.501  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+19"
}

Globular "Bol 20:SKHB 73"
{
	RA          	  0.682017  # [hours]
	Dec         	  41.69036  # [degrees]
	Distance    	2.5528e+06  # [ly]
	Radius      	     105.7  # [ly]
	CoreRadius  	    0.0037  # [arcmin]
	KingConcentration     1.58  # c = log10(r_t/r_c)
	AbsMag      	    -9.558  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+20"
}

Globular "Bol 22:SKHB 74"
{
	RA          	  0.683078  # [hours]
	Dec         	  41.41172  # [degrees]
	Distance    	2.5939e+06  # [ly]
	Radius      	     69.47  # [ly]
	CoreRadius  	    0.0041  # [arcmin]
	KingConcentration     1.35  # c = log10(r_t/r_c)
	AbsMag      	    -7.143  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+22"
}

Globular "Bol 247"
{
	RA          	   0.68395  # [hours]
	Dec         	  41.00875  # [degrees]
	Distance    	2.5998e+06  # [ly]
	Radius      	       210  # [ly]
	CoreRadius  	     0.042  # [arcmin]
	KingConcentration     0.82  # c = log10(r_t/r_c)
	AbsMag      	    -6.248  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+247"
}

Globular "Bol D15"
{
	RA          	  0.684091  # [hours]
	Dec         	  41.11008  # [degrees]
	Distance    	2.5543e+06  # [ly]
	Radius      	     2.808  # [ly]
	CoreRadius  	    0.0038  # [arcmin]
	KingConcentration    2.395  # c = log10(r_t/r_c)
	AbsMag      	    -5.769  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+D15"
}

Globular "[KLG2007] GC1 19"
{
	RA          	  0.684711  # [hours]
	Dec         	  41.47719  # [degrees]
	Distance    	2.5426e+06  # [ly]
	Radius      	     62.62  # [ly]
	CoreRadius  	    0.0013  # [arcmin]
	KingConcentration      1.8  # c = log10(r_t/r_c)
	AbsMag      	    -5.559  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=%5BKLG2007%5D+GC1+19"
}

Globular "KWC 37:Bol 248"
{
	RA          	  0.685538  # [hours]
	Dec         	 40.883639  # [degrees]
	Distance    	2.5578e+06  # [ly]
	Radius      	     101.4  # [ly]
	CoreRadius  	    0.0072  # [arcmin]
	KingConcentration     1.28  # c = log10(r_t/r_c)
	AbsMag      	    -6.412  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=KWC+37"
}

Globular "Bol 24:SKHB 82"
{
	RA          	  0.686625  # [hours]
	Dec         	  41.76369  # [degrees]
	Distance    	2.5205e+06  # [ly]
	Radius      	     72.08  # [ly]
	CoreRadius  	    0.0014  # [arcmin]
	KingConcentration     1.86  # c = log10(r_t/r_c)
	AbsMag      	     -7.64  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+24"
}

Globular "M31GC J004112+410532"
{
	RA          	  0.686733  # [hours]
	Dec         	  41.09133  # [degrees]
	Distance    	2.5164e+06  # [ly]
	Radius      	      16.2  # [ly]
	CoreRadius  	    0.0221  # [arcmin]
	KingConcentration    0.814  # c = log10(r_t/r_c)
	AbsMag      	    -8.367  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=M31GC+J004112%2B410532"
}

Globular "Bol 25:SKHB 84"
{
	RA          	  0.686819  # [hours]
	Dec         	  41.00781  # [degrees]
	Distance    	2.5523e+06  # [ly]
	Radius      	     45.34  # [ly]
	CoreRadius  	    0.0041  # [arcmin]
	KingConcentration     1.17  # c = log10(r_t/r_c)
	AbsMag      	    -7.698  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+25"
}

Globular "[KLG2007] GC1 20"
{
	RA          	  0.687041  # [hours]
	Dec         	  41.16169  # [degrees]
	Distance    	2.5789e+06  # [ly]
	Radius      	     46.31  # [ly]
	CoreRadius  	    0.0118  # [arcmin]
	KingConcentration     0.72  # c = log10(r_t/r_c)
	AbsMag      	     -4.81  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=%5BKLG2007%5D+GC1+20"
}

Globular "Bol 28:SKHB 88"
{
	RA          	  0.687913  # [hours]
	Dec         	 40.984344  # [degrees]
	Distance    	2.5662e+06  # [ly]
	Radius      	     68.49  # [ly]
	CoreRadius  	    0.0054  # [arcmin]
	KingConcentration     1.23  # c = log10(r_t/r_c)
	AbsMag      	    -7.579  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+28"
}

Globular "Bol D20:SKHB 89"
{
	RA          	  0.688122  # [hours]
	Dec         	  41.13589  # [degrees]
	Distance    	2.5393e+06  # [ly]
	Radius      	       182  # [ly]
	CoreRadius  	     0.002  # [arcmin]
	KingConcentration      2.1  # c = log10(r_t/r_c)
	AbsMag      	    -6.986  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+D20"
}

Globular "Bol 29:SKHB 90"
{
	RA          	  0.688289  # [hours]
	Dec         	  41.00639  # [degrees]
	Distance    	2.6268e+06  # [ly]
	Radius      	     160.1  # [ly]
	CoreRadius  	    0.0056  # [arcmin]
	KingConcentration     1.57  # c = log10(r_t/r_c)
	AbsMag      	     -7.88  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+29"
}

Globular "KWC 42:Bol 30:SKHB 91"
{
	RA          	  0.688534  # [hours]
	Dec         	 40.954436  # [degrees]
	Distance    	2.6233e+06  # [ly]
	Radius      	      49.9  # [ly]
	CoreRadius  	    0.0045  # [arcmin]
	KingConcentration     1.16  # c = log10(r_t/r_c)
	AbsMag      	    -7.207  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=KWC+42"
}

Globular "KWC 43:Bol 31:SKHB 92"
{
	RA          	  0.689143  # [hours]
	Dec         	 40.984619  # [degrees]
	Distance    	2.5192e+06  # [ly]
	Radius      	     42.73  # [ly]
	CoreRadius  	    0.0051  # [arcmin]
	KingConcentration     1.06  # c = log10(r_t/r_c)
	AbsMag      	    -6.719  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=KWC+43"
}

Globular "Bol 32:SKHB 93"
{
	RA          	  0.689311  # [hours]
	Dec         	  41.29169  # [degrees]
	Distance    	2.5252e+06  # [ly]
	Radius      	     55.45  # [ly]
	CoreRadius  	    0.0027  # [arcmin]
	KingConcentration     1.44  # c = log10(r_t/r_c)
	AbsMag      	    -6.834  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+32"
}

Globular "[KLG2007] GC1 26"
{
	RA          	  0.690175  # [hours]
	Dec         	  40.60103  # [degrees]
	Distance    	 2.557e+06  # [ly]
	Radius      	     22.83  # [ly]
	CoreRadius  	     0.002  # [arcmin]
	KingConcentration     1.18  # c = log10(r_t/r_c)
	AbsMag      	    -6.311  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=%5BKLG2007%5D+GC1+26"
}

Globular "Bol 33:SKHB 95"
{
	RA          	  0.690667  # [hours]
	Dec         	  41.00383  # [degrees]
	Distance    	2.5327e+06  # [ly]
	Radius      	     116.8  # [ly]
	CoreRadius  	    0.0021  # [arcmin]
	KingConcentration     1.88  # c = log10(r_t/r_c)
	AbsMag      	    -6.771  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+33"
}

Globular "Bol 34:SKHB 96"
{
	RA          	  0.691143  # [hours]
	Dec         	 40.897206  # [degrees]
	Distance    	2.6045e+06  # [ly]
	Radius      	     87.41  # [ly]
	CoreRadius  	    0.0025  # [arcmin]
	KingConcentration     1.66  # c = log10(r_t/r_c)
	AbsMag      	    -9.014  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+34"
}

Globular "Bol 457:SKHB 97"
{
	RA          	  0.691447  # [hours]
	Dec         	  42.31033  # [degrees]
	Distance    	2.5687e+06  # [ly]
	Radius      	     68.17  # [ly]
	CoreRadius  	    0.0263  # [arcmin]
	KingConcentration     0.54  # c = log10(r_t/r_c)
	AbsMag      	    -7.569  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+457"
}

Globular "Bol 35"
{
	RA          	  0.692386  # [hours]
	Dec         	  41.64239  # [degrees]
	Distance    	2.5597e+06  # [ly]
	Radius      	     53.16  # [ly]
	CoreRadius  	    0.0015  # [arcmin]
	KingConcentration     1.69  # c = log10(r_t/r_c)
	AbsMag      	    -6.994  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+35"
}

Globular "Bol 37"
{
	RA          	  0.693047  # [hours]
	Dec         	  41.24858  # [degrees]
	Distance    	2.5114e+06  # [ly]
	Radius      	     102.7  # [ly]
	CoreRadius  	    0.0097  # [arcmin]
	KingConcentration     1.16  # c = log10(r_t/r_c)
	AbsMag      	    -7.572  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+37"
}

Globular "Bol 38:SKHB 98"
{
	RA          	  0.693319  # [hours]
	Dec         	  41.32078  # [degrees]
	Distance    	2.5782e+06  # [ly]
	Radius      	     50.55  # [ly]
	CoreRadius  	    0.0049  # [arcmin]
	KingConcentration     1.14  # c = log10(r_t/r_c)
	AbsMag      	    -7.979  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+38"
}

Globular "Bol 39:SKHB 101"
{
	RA          	  0.693853  # [hours]
	Dec         	  41.34717  # [degrees]
	Distance    	2.5225e+06  # [ly]
	Radius      	     113.8  # [ly]
	CoreRadius  	     0.003  # [arcmin]
	KingConcentration     1.71  # c = log10(r_t/r_c)
	AbsMag      	    -8.272  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+39"
}

Globular "Bol 42:SKHB 104"
{
	RA          	  0.694911  # [hours]
	Dec         	  41.12394  # [degrees]
	Distance    	2.5126e+06  # [ly]
	Radius      	     60.34  # [ly]
	CoreRadius  	    0.0038  # [arcmin]
	KingConcentration     1.34  # c = log10(r_t/r_c)
	AbsMag      	    -8.273  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+42"
}

Globular "Bol 343:SKHB 105"
{
	RA          	  0.695305  # [hours]
	Dec         	  40.20622  # [degrees]
	Distance    	2.5902e+06  # [ly]
	Radius      	     113.5  # [ly]
	CoreRadius  	    0.0017  # [arcmin]
	KingConcentration     1.94  # c = log10(r_t/r_c)
	AbsMag      	     -7.81  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+343"
}

Globular "Bol 46:SKHB 109"
{
	RA          	  0.695728  # [hours]
	Dec         	   41.7745  # [degrees]
	Distance    	2.5834e+06  # [ly]
	Radius      	     62.95  # [ly]
	CoreRadius  	    0.0033  # [arcmin]
	KingConcentration     1.41  # c = log10(r_t/r_c)
	AbsMag      	    -6.684  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+46"
}

Globular "Bol 47:SKHB 111"
{
	RA          	  0.695989  # [hours]
	Dec         	  41.70108  # [degrees]
	Distance    	2.5148e+06  # [ly]
	Radius      	     68.17  # [ly]
	CoreRadius  	    0.0115  # [arcmin]
	KingConcentration     0.91  # c = log10(r_t/r_c)
	AbsMag      	    -6.925  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+47"
}

Globular "Bol 50:SKHB 113"
{
	RA          	  0.696189  # [hours]
	Dec         	  41.53847  # [degrees]
	Distance    	2.5666e+06  # [ly]
	Radius      	     73.06  # [ly]
	CoreRadius  	    0.0015  # [arcmin]
	KingConcentration     1.81  # c = log10(r_t/r_c)
	AbsMag      	     -7.74  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+50"
}

Globular "[KLG2007] GC1 35"
{
	RA          	  0.696467  # [hours]
	Dec         	  41.87619  # [degrees]
	Distance    	2.5585e+06  # [ly]
	Radius      	      69.8  # [ly]
	CoreRadius  	    0.0033  # [arcmin]
	KingConcentration     1.45  # c = log10(r_t/r_c)
	AbsMag      	    -9.603  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=%5BKLG2007%5D+GC1+35"
}

Globular "SK036A"
{
	RA          	  0.696495  # [hours]
	Dec         	  40.85228  # [degrees]
	Distance    	2.5788e+06  # [ly]
	Radius      	     29.68  # [ly]
	CoreRadius  	    0.0056  # [arcmin]
	KingConcentration     0.85  # c = log10(r_t/r_c)
	AbsMag      	     -5.06  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NAME+SK036A"
}

Globular "Bol 54:SKHB 115"
{
	RA          	  0.696578  # [hours]
	Dec         	  41.01539  # [degrees]
	Distance    	2.6027e+06  # [ly]
	Radius      	     57.73  # [ly]
	CoreRadius  	    0.0039  # [arcmin]
	KingConcentration     1.29  # c = log10(r_t/r_c)
	AbsMag      	     -6.35  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+54"
}

Globular "Bol 56:SKHB 117"
{
	RA          	  0.697547  # [hours]
	Dec         	  40.96117  # [degrees]
	Distance    	2.6264e+06  # [ly]
	Radius      	     105.7  # [ly]
	CoreRadius  	    0.0018  # [arcmin]
	KingConcentration     1.88  # c = log10(r_t/r_c)
	AbsMag      	     -7.24  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+56"
}

Globular "Bol 57:SKHB 118"
{
	RA          	  0.698003  # [hours]
	Dec         	  40.86806  # [degrees]
	Distance    	2.5606e+06  # [ly]
	Radius      	     110.9  # [ly]
	CoreRadius  	     0.001  # [arcmin]
	KingConcentration     2.19  # c = log10(r_t/r_c)
	AbsMag      	    -6.895  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+57"
}

Globular "Bol 60:SKHB 121"
{
	RA          	  0.699167  # [hours]
	Dec         	  41.08736  # [degrees]
	Distance    	2.5515e+06  # [ly]
	Radius      	     26.74  # [ly]
	CoreRadius  	    0.0097  # [arcmin]
	KingConcentration     0.57  # c = log10(r_t/r_c)
	AbsMag      	    -7.787  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+60"
}

Globular "Bol 61:SKHB 122"
{
	RA          	  0.700033  # [hours]
	Dec         	  41.49328  # [degrees]
	Distance    	2.5843e+06  # [ly]
	Radius      	     99.48  # [ly]
	CoreRadius  	    0.0025  # [arcmin]
	KingConcentration     1.72  # c = log10(r_t/r_c)
	AbsMag      	    -7.905  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+61"
}

Globular "Bol 63:SKHB 124"
{
	RA          	  0.700239  # [hours]
	Dec         	  41.48603  # [degrees]
	Distance    	2.5866e+06  # [ly]
	Radius      	     82.52  # [ly]
	CoreRadius  	    0.0024  # [arcmin]
	KingConcentration     1.66  # c = log10(r_t/r_c)
	AbsMag      	    -8.767  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+63"
}

Globular "Bol 65:SKHB 126"
{
	RA          	  0.700539  # [hours]
	Dec         	  40.67025  # [degrees]
	Distance    	2.6355e+06  # [ly]
	Radius      	     46.97  # [ly]
	CoreRadius  	    0.0102  # [arcmin]
	KingConcentration     0.78  # c = log10(r_t/r_c)
	AbsMag      	    -7.707  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+65"
}

Globular "Bol 344:SKHB 127"
{
	RA          	  0.700825  # [hours]
	Dec         	  41.86725  # [degrees]
	Distance    	2.6045e+06  # [ly]
	Radius      	      99.8  # [ly]
	CoreRadius  	    0.0029  # [arcmin]
	KingConcentration     1.66  # c = log10(r_t/r_c)
	AbsMag      	    -8.562  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+344"
}

Globular "Bol 66:SKHB 128"
{
	RA          	  0.700859  # [hours]
	Dec         	  40.74642  # [degrees]
	Distance    	2.5256e+06  # [ly]
	Radius      	      1.97  # [ly]
	CoreRadius  	    0.0027  # [arcmin]
	KingConcentration    2.079  # c = log10(r_t/r_c)
	AbsMag      	    -7.025  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+66"
}

Globular "Bol 67:SKHB 129"
{
	RA          	  0.700883  # [hours]
	Dec         	  41.07325  # [degrees]
	Distance    	2.5827e+06  # [ly]
	Radius      	     40.12  # [ly]
	CoreRadius  	    0.0035  # [arcmin]
	KingConcentration     1.18  # c = log10(r_t/r_c)
	AbsMag      	    -7.293  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+67"
}

Globular "Bol 68:SKHB 130"
{
	RA          	  0.700891  # [hours]
	Dec         	  40.98061  # [degrees]
	Distance    	2.6025e+06  # [ly]
	Radius      	       105  # [ly]
	CoreRadius  	    0.0021  # [arcmin]
	KingConcentration     1.81  # c = log10(r_t/r_c)
	AbsMag      	     -8.27  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+68"
}

Globular "KHM31 162:Bol 257"
{
	RA          	  0.700914  # [hours]
	Dec         	  40.97053  # [degrees]
	Distance    	2.5073e+06  # [ly]
	Radius      	     65.88  # [ly]
	CoreRadius  	    0.0019  # [arcmin]
	KingConcentration     1.68  # c = log10(r_t/r_c)
	AbsMag      	    -6.669  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=KHM31+162"
}

Globular "Bol 461:SKHB 131"
{
	RA          	  0.701183  # [hours]
	Dec         	  42.05739  # [degrees]
	Distance    	2.5929e+06  # [ly]
	Radius      	     85.78  # [ly]
	CoreRadius  	    0.0032  # [arcmin]
	KingConcentration     1.55  # c = log10(r_t/r_c)
	AbsMag      	    -6.978  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+461"
}

Globular "Bol 73:SKHB 134"
{
	RA          	  0.702033  # [hours]
	Dec         	  40.98925  # [degrees]
	Distance    	2.5532e+06  # [ly]
	Radius      	     95.24  # [ly]
	CoreRadius  	    0.0013  # [arcmin]
	KingConcentration     1.98  # c = log10(r_t/r_c)
	AbsMag      	    -8.498  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+73"
}

Globular "Bol 74:SKHB 135"
{
	RA          	  0.702236  # [hours]
	Dec         	  41.72269  # [degrees]
	Distance    	2.6174e+06  # [ly]
	Radius      	     99.15  # [ly]
	CoreRadius  	    0.0051  # [arcmin]
	KingConcentration     1.41  # c = log10(r_t/r_c)
	AbsMag      	    -7.872  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+74"
}

Globular "Bol 76:SKHB 138"
{
	RA          	  0.702841  # [hours]
	Dec         	  41.08947  # [degrees]
	Distance    	2.5371e+06  # [ly]
	Radius      	     88.39  # [ly]
	CoreRadius  	    0.0012  # [arcmin]
	KingConcentration     1.99  # c = log10(r_t/r_c)
	AbsMag      	    -7.785  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+76"
}

Globular "Bol 81:SKHB 142"
{
	RA          	  0.703775  # [hours]
	Dec         	  40.81083  # [degrees]
	Distance    	2.5988e+06  # [ly]
	Radius      	     2.379  # [ly]
	CoreRadius  	    0.0031  # [arcmin]
	KingConcentration    1.937  # c = log10(r_t/r_c)
	AbsMag      	    -7.027  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+81"
}

Globular "Bol 345:SKHB 143"
{
	RA          	  0.703925  # [hours]
	Dec         	  40.29344  # [degrees]
	Distance    	2.5448e+06  # [ly]
	Radius      	     88.71  # [ly]
	CoreRadius  	    0.0025  # [arcmin]
	KingConcentration     1.68  # c = log10(r_t/r_c)
	AbsMag      	    -7.621  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+345"
}

Globular "Bol 462"
{
	RA          	  0.704089  # [hours]
	Dec         	  42.02681  # [degrees]
	Distance    	2.5682e+06  # [ly]
	Radius      	     137.6  # [ly]
	CoreRadius  	    0.0043  # [arcmin]
	KingConcentration     1.63  # c = log10(r_t/r_c)
	AbsMag      	    -6.421  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+462"
}

Globular "Bol 83:SKHB 146"
{
	RA          	  0.704567  # [hours]
	Dec         	  41.75572  # [degrees]
	Distance    	 2.581e+06  # [ly]
	Radius      	     136.7  # [ly]
	CoreRadius  	    0.0118  # [arcmin]
	KingConcentration     1.19  # c = log10(r_t/r_c)
	AbsMag      	    -7.402  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+83"
}

Globular "Bol 85:SKHB 147"
{
	RA          	  0.705067  # [hours]
	Dec         	  40.66589  # [degrees]
	Distance    	2.5229e+06  # [ly]
	Radius      	     103.4  # [ly]
	CoreRadius  	    0.0029  # [arcmin]
	KingConcentration     1.69  # c = log10(r_t/r_c)
	AbsMag      	    -7.602  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+85"
}

Globular "KHM31 384:Bol 90"
{
	RA          	  0.705853  # [hours]
	Dec         	  41.04933  # [degrees]
	Distance    	2.6089e+06  # [ly]
	Radius      	     26.74  # [ly]
	CoreRadius  	    0.0119  # [arcmin]
	KingConcentration     0.47  # c = log10(r_t/r_c)
	AbsMag      	    -6.075  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=KHM31+384"
}

Globular "Bol 347:SKHB 154"
{
	RA          	  0.706358  # [hours]
	Dec         	  41.90761  # [degrees]
	Distance    	2.5345e+06  # [ly]
	Radius      	     138.3  # [ly]
	CoreRadius  	    0.0044  # [arcmin]
	KingConcentration     1.63  # c = log10(r_t/r_c)
	AbsMag      	    -7.952  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+347"
}

Globular "Bol 348:SKHB 153"
{
	RA          	  0.706367  # [hours]
	Dec         	  41.87456  # [degrees]
	Distance    	2.5242e+06  # [ly]
	Radius      	     70.45  # [ly]
	CoreRadius  	    0.0012  # [arcmin]
	KingConcentration     1.89  # c = log10(r_t/r_c)
	AbsMag      	    -7.653  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+348"
}

Globular "Bol 95:SKHB 157"
{
	RA          	  0.707167  # [hours]
	Dec         	  41.09342  # [degrees]
	Distance    	2.6425e+06  # [ly]
	Radius      	     71.75  # [ly]
	CoreRadius  	    0.0078  # [arcmin]
	KingConcentration     1.08  # c = log10(r_t/r_c)
	AbsMag      	    -8.343  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+95"
}

Globular "Bol 350:SKHB 162"
{
	RA          	  0.707897  # [hours]
	Dec         	  40.41422  # [degrees]
	Distance    	2.5502e+06  # [ly]
	Radius      	     143.8  # [ly]
	CoreRadius  	    0.0093  # [arcmin]
	KingConcentration     1.32  # c = log10(r_t/r_c)
	AbsMag      	    -7.726  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+350"
}

Globular "Bol 100:SKHB 163"
{
	RA          	  0.708047  # [hours]
	Dec         	  40.83219  # [degrees]
	Distance    	2.6384e+06  # [ly]
	Radius      	     78.93  # [ly]
	CoreRadius  	    0.0124  # [arcmin]
	KingConcentration     0.92  # c = log10(r_t/r_c)
	AbsMag      	     -6.86  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+100"
}

Globular "M31GC J004233+412017"
{
	RA          	    0.7092  # [hours]
	Dec         	    41.338  # [degrees]
	Distance    	2.6206e+06  # [ly]
	Radius      	     1.152  # [ly]
	CoreRadius  	    0.0015  # [arcmin]
	KingConcentration    1.752  # c = log10(r_t/r_c)
	AbsMag      	    -7.105  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=M31GC+J004233%2B412017"
}

Globular "Bol 111:SKHB 173"
{
	RA          	  0.709214  # [hours]
	Dec         	  41.00733  # [degrees]
	Distance    	 2.532e+06  # [ly]
	Radius      	     64.58  # [ly]
	CoreRadius  	    0.0032  # [arcmin]
	KingConcentration     1.44  # c = log10(r_t/r_c)
	AbsMag      	     -7.79  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+111"
}

Globular "[KLG2007] GC1 52"
{
	RA          	  0.710367  # [hours]
	Dec         	  41.84822  # [degrees]
	Distance    	2.5841e+06  # [ly]
	Radius      	     44.68  # [ly]
	CoreRadius  	    0.0071  # [arcmin]
	KingConcentration     0.92  # c = log10(r_t/r_c)
	AbsMag      	    -7.134  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=%5BKLG2007%5D+GC1+52"
}

Globular "Bol 351:SKHB 179"
{
	RA          	  0.710547  # [hours]
	Dec         	  42.19192  # [degrees]
	Distance    	2.5536e+06  # [ly]
	Radius      	     130.8  # [ly]
	CoreRadius  	     0.009  # [arcmin]
	KingConcentration     1.29  # c = log10(r_t/r_c)
	AbsMag      	    -6.916  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+351"
}

Globular "Bol 352:SKHB 180"
{
	RA          	  0.710608  # [hours]
	Dec         	  42.03697  # [degrees]
	Distance    	2.5926e+06  # [ly]
	Radius      	     104.7  # [ly]
	CoreRadius  	    0.0033  # [arcmin]
	KingConcentration     1.63  # c = log10(r_t/r_c)
	AbsMag      	    -7.962  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+352"
}

Globular "[KLG2007] GC1 53"
{
	RA          	  0.711336  # [hours]
	Dec         	    40.298  # [degrees]
	Distance    	2.5191e+06  # [ly]
	Radius      	       107  # [ly]
	CoreRadius  	    0.0007  # [arcmin]
	KingConcentration     2.34  # c = log10(r_t/r_c)
	AbsMag      	    -7.729  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=%5BKLG2007%5D+GC1+53"
}

Globular "Bol 125:SKHB 183"
{
	RA          	  0.711742  # [hours]
	Dec         	  41.09197  # [degrees]
	Distance    	2.5115e+06  # [ly]
	Radius      	     112.5  # [ly]
	CoreRadius  	    0.0005  # [arcmin]
	KingConcentration     2.47  # c = log10(r_t/r_c)
	AbsMag      	    -7.923  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+125"
}

Globular "M31GC J004243+402927"
{
	RA          	  0.711811  # [hours]
	Dec         	  40.49078  # [degrees]
	Distance    	2.5541e+06  # [ly]
	Radius      	     23.81  # [ly]
	CoreRadius  	    0.0073  # [arcmin]
	KingConcentration     0.64  # c = log10(r_t/r_c)
	AbsMag      	    -6.599  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=M31GC+J004243%2B402927"
}

Globular "Bol 354:SKHB 186"
{
	RA          	  0.713222  # [hours]
	Dec         	  42.00711  # [degrees]
	Distance    	2.5994e+06  # [ly]
	Radius      	     39.46  # [ly]
	CoreRadius  	    0.0203  # [arcmin]
	KingConcentration     0.41  # c = log10(r_t/r_c)
	AbsMag      	    -6.697  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+354"
}

Globular "[KLG2007] GC1 55"
{
	RA          	  0.714405  # [hours]
	Dec         	  40.73608  # [degrees]
	Distance    	 2.606e+06  # [ly]
	Radius      	     98.83  # [ly]
	CoreRadius  	    0.0108  # [arcmin]
	KingConcentration     1.08  # c = log10(r_t/r_c)
	AbsMag      	    -8.233  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=%5BKLG2007%5D+GC1+55"
}

Globular "Bol 137:SKHB 195"
{
	RA          	  0.714997  # [hours]
	Dec         	  41.53733  # [degrees]
	Distance    	2.5272e+06  # [ly]
	Radius      	     229.3  # [ly]
	CoreRadius  	    0.0044  # [arcmin]
	KingConcentration     1.85  # c = log10(r_t/r_c)
	AbsMag      	    -6.776  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+137"
}

Globular "Bol 141:SKHB 197"
{
	RA          	  0.716469  # [hours]
	Dec         	   41.5465  # [degrees]
	Distance    	2.5898e+06  # [ly]
	Radius      	     146.4  # [ly]
	CoreRadius  	    0.0018  # [arcmin]
	KingConcentration     2.03  # c = log10(r_t/r_c)
	AbsMag      	    -7.669  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+141"
}

Globular "Bol 266"
{
	RA          	  0.717645  # [hours]
	Dec         	  41.67542  # [degrees]
	Distance    	2.6138e+06  # [ly]
	Radius      	     37.51  # [ly]
	CoreRadius  	    0.0058  # [arcmin]
	KingConcentration     0.93  # c = log10(r_t/r_c)
	AbsMag      	    -6.249  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+266"
}

Globular "Bol 149:SKHB 201"
{
	RA          	  0.718186  # [hours]
	Dec         	  41.57422  # [degrees]
	Distance    	2.6175e+06  # [ly]
	Radius      	     158.8  # [ly]
	CoreRadius  	    0.0028  # [arcmin]
	KingConcentration     1.88  # c = log10(r_t/r_c)
	AbsMag      	    -7.492  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+149"
}

Globular "Bol 467:SKHB 202"
{
	RA          	  0.718453  # [hours]
	Dec         	  42.03033  # [degrees]
	Distance    	2.6035e+06  # [ly]
	Radius      	     148.4  # [ly]
	CoreRadius  	    0.0041  # [arcmin]
	KingConcentration     1.68  # c = log10(r_t/r_c)
	AbsMag      	    -7.081  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+467"
}

Globular "Bol 269"
{
	RA          	  0.718714  # [hours]
	Dec         	  41.45908  # [degrees]
	Distance    	 2.562e+06  # [ly]
	Radius      	     162.8  # [ly]
	CoreRadius  	     0.001  # [arcmin]
	KingConcentration     2.32  # c = log10(r_t/r_c)
	AbsMag      	    -5.646  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+269"
}

Globular "Bol 356:SKHB 206"
{
	RA          	  0.719545  # [hours]
	Dec         	    41.842  # [degrees]
	Distance    	2.5826e+06  # [ly]
	Radius      	     104.4  # [ly]
	CoreRadius  	    0.0028  # [arcmin]
	KingConcentration     1.69  # c = log10(r_t/r_c)
	AbsMag      	    -7.603  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+356"
}

Globular "Bol 170:SKHB 221"
{
	RA          	  0.723192  # [hours]
	Dec         	  40.84489  # [degrees]
	Distance    	2.5519e+06  # [ly]
	Radius      	     70.45  # [ly]
	CoreRadius  	    0.0015  # [arcmin]
	KingConcentration     1.81  # c = log10(r_t/r_c)
	AbsMag      	    -7.067  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+170"
}

Globular "[KLG2007] GC1 66"
{
	RA          	  0.723355  # [hours]
	Dec         	  41.64508  # [degrees]
	Distance    	2.5606e+06  # [ly]
	Radius      	     105.7  # [ly]
	CoreRadius  	    0.0006  # [arcmin]
	KingConcentration     2.36  # c = log10(r_t/r_c)
	AbsMag      	    -4.925  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=%5BKLG2007%5D+GC1+66"
}

Globular "Bol 272"
{
	RA          	   0.72375  # [hours]
	Dec         	  41.61994  # [degrees]
	Distance    	2.5318e+06  # [ly]
	Radius      	     168.9  # [ly]
	CoreRadius  	    0.0087  # [arcmin]
	KingConcentration     1.42  # c = log10(r_t/r_c)
	AbsMag      	     -6.22  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+272"
}

Globular "Bol 174:SKHB 226"
{
	RA          	  0.725083  # [hours]
	Dec         	  41.64897  # [degrees]
	Distance    	2.6287e+06  # [ly]
	Radius      	       120  # [ly]
	CoreRadius  	    0.0109  # [arcmin]
	KingConcentration     1.16  # c = log10(r_t/r_c)
	AbsMag      	    -9.132  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+174"
}

Globular "Bol 177:SKHB 228"
{
	RA          	  0.725141  # [hours]
	Dec         	  41.09508  # [degrees]
	Distance    	2.5887e+06  # [ly]
	Radius      	     185.9  # [ly]
	CoreRadius  	    0.0006  # [arcmin]
	KingConcentration     2.58  # c = log10(r_t/r_c)
	AbsMag      	    -6.198  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+177"
}

Globular "Bol 181:SKHB 232"
{
	RA          	  0.725683  # [hours]
	Dec         	  41.48536  # [degrees]
	Distance    	2.5749e+06  # [ly]
	Radius      	     79.58  # [ly]
	CoreRadius  	    0.0034  # [arcmin]
	KingConcentration     1.49  # c = log10(r_t/r_c)
	AbsMag      	    -7.557  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+181"
}

Globular "Bol 183:SKHB 234"
{
	RA          	  0.726925  # [hours]
	Dec         	  41.03397  # [degrees]
	Distance    	2.5935e+06  # [ly]
	Radius      	     109.9  # [ly]
	CoreRadius  	     0.002  # [arcmin]
	KingConcentration     1.86  # c = log10(r_t/r_c)
	AbsMag      	    -8.512  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+183"
}

Globular "Bol 184:SKHB 236"
{
	RA          	  0.727083  # [hours]
	Dec         	  41.60961  # [degrees]
	Distance    	2.5816e+06  # [ly]
	Radius      	     94.26  # [ly]
	CoreRadius  	    0.0052  # [arcmin]
	KingConcentration     1.38  # c = log10(r_t/r_c)
	AbsMag      	    -7.032  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+184"
}

Globular "Bol 187:SKHB 237"
{
	RA          	  0.727395  # [hours]
	Dec         	  41.49633  # [degrees]
	Distance    	2.6214e+06  # [ly]
	Radius      	     44.03  # [ly]
	CoreRadius  	    0.0174  # [arcmin]
	KingConcentration     0.52  # c = log10(r_t/r_c)
	AbsMag      	    -7.236  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+187"
}

Globular "Bol 189:SKHB 240"
{
	RA          	  0.728442  # [hours]
	Dec         	  41.58983  # [degrees]
	Distance    	2.6267e+06  # [ly]
	Radius      	     113.8  # [ly]
	CoreRadius  	    0.0075  # [arcmin]
	KingConcentration      1.3  # c = log10(r_t/r_c)
	AbsMag      	     -7.47  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+189"
}

Globular "Bol 190:SKHB 241"
{
	RA          	  0.728717  # [hours]
	Dec         	  41.56833  # [degrees]
	Distance    	 2.509e+06  # [ly]
	Radius      	     90.67  # [ly]
	CoreRadius  	    0.0027  # [arcmin]
	KingConcentration     1.66  # c = log10(r_t/r_c)
	AbsMag      	     -7.52  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+190"
}

Globular "[KLG2007] GC1 71"
{
	RA          	  0.729558  # [hours]
	Dec         	  41.65794  # [degrees]
	Distance    	2.5198e+06  # [ly]
	Radius      	     73.71  # [ly]
	CoreRadius  	    0.0086  # [arcmin]
	KingConcentration     1.07  # c = log10(r_t/r_c)
	AbsMag      	     -4.37  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=%5BKLG2007%5D+GC1+71"
}

Globular "Bol 197:SKHB 247"
{
	RA          	  0.730478  # [hours]
	Dec         	  41.50281  # [degrees]
	Distance    	2.5791e+06  # [ly]
	Radius      	     129.2  # [ly]
	CoreRadius  	    0.0015  # [arcmin]
	KingConcentration     2.05  # c = log10(r_t/r_c)
	AbsMag      	     -6.72  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+197"
}

Globular "Bol 199:SKHB 248"
{
	RA          	  0.730505  # [hours]
	Dec         	  40.97072  # [degrees]
	Distance    	2.6165e+06  # [ly]
	Radius      	     52.18  # [ly]
	CoreRadius  	    0.0045  # [arcmin]
	KingConcentration     1.18  # c = log10(r_t/r_c)
	AbsMag      	    -7.001  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+199"
}

Globular "Bol 198:SKHB 249"
{
	RA          	  0.730583  # [hours]
	Dec         	  41.53133  # [degrees]
	Distance    	2.5674e+06  # [ly]
	Radius      	     30.66  # [ly]
	CoreRadius  	    0.0076  # [arcmin]
	KingConcentration     0.73  # c = log10(r_t/r_c)
	AbsMag      	     -6.57  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+198"
}

Globular "Bol 200"
{
	RA          	  0.730672  # [hours]
	Dec         	  41.48961  # [degrees]
	Distance    	2.6404e+06  # [ly]
	Radius      	      63.6  # [ly]
	CoreRadius  	    0.0131  # [arcmin]
	KingConcentration      0.8  # c = log10(r_t/r_c)
	AbsMag      	    -6.251  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+200"
}

Globular "Bol 202:SKHB 251"
{
	RA          	  0.731855  # [hours]
	Dec         	  41.00894  # [degrees]
	Distance    	2.5702e+06  # [ly]
	Radius      	     61.97  # [ly]
	CoreRadius  	    0.0028  # [arcmin]
	KingConcentration     1.47  # c = log10(r_t/r_c)
	AbsMag      	    -6.713  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+202"
}

Globular "Bol 203:SKHB 252"
{
	RA          	  0.732172  # [hours]
	Dec         	  41.54306  # [degrees]
	Distance    	2.5951e+06  # [ly]
	Radius      	     203.5  # [ly]
	CoreRadius  	    0.0002  # [arcmin]
	KingConcentration     3.14  # c = log10(r_t/r_c)
	AbsMag      	    -7.814  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+203"
}

Globular "Bol 361:SKHB 255"
{
	RA          	  0.732525  # [hours]
	Dec         	  40.23375  # [degrees]
	Distance    	2.6047e+06  # [ly]
	Radius      	     113.8  # [ly]
	CoreRadius  	    0.0057  # [arcmin]
	KingConcentration     1.42  # c = log10(r_t/r_c)
	AbsMag      	    -7.462  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+361"
}

Globular "Bol 206:SKHB 257"
{
	RA          	   0.73295  # [hours]
	Dec         	  41.50503  # [degrees]
	Distance    	2.5705e+06  # [ly]
	Radius      	     75.34  # [ly]
	CoreRadius  	    0.0068  # [arcmin]
	KingConcentration     1.17  # c = log10(r_t/r_c)
	AbsMag      	    -9.423  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+206"
}

Globular "Bol 207:SKHB 258"
{
	RA          	  0.733183  # [hours]
	Dec         	  41.10297  # [degrees]
	Distance    	2.5894e+06  # [ly]
	Radius      	     69.15  # [ly]
	CoreRadius  	    0.0043  # [arcmin]
	KingConcentration     1.33  # c = log10(r_t/r_c)
	AbsMag      	    -7.229  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+207"
}

Globular "Bol 208:SKHB 259"
{
	RA          	  0.733355  # [hours]
	Dec         	  41.38653  # [degrees]
	Distance    	2.5167e+06  # [ly]
	Radius      	     186.6  # [ly]
	CoreRadius  	    0.0029  # [arcmin]
	KingConcentration     1.95  # c = log10(r_t/r_c)
	AbsMag      	    -6.387  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+208"
}

Globular "M31GC J004401+411713"
{
	RA          	  0.733567  # [hours]
	Dec         	  41.28678  # [degrees]
	Distance    	2.6314e+06  # [ly]
	Radius      	     80.23  # [ly]
	CoreRadius  	    0.0054  # [arcmin]
	KingConcentration     1.29  # c = log10(r_t/r_c)
	AbsMag      	    -7.624  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=M31GC+J004401%2B411713"
}

Globular "Bol 209:SKHB 261"
{
	RA          	  0.734064  # [hours]
	Dec         	  41.42406  # [degrees]
	Distance    	2.5842e+06  # [ly]
	Radius      	      42.4  # [ly]
	CoreRadius  	    0.0032  # [arcmin]
	KingConcentration     1.25  # c = log10(r_t/r_c)
	AbsMag      	    -7.895  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+209"
}

Globular "Bol 211:SKHB 262"
{
	RA          	  0.734141  # [hours]
	Dec         	  41.33464  # [degrees]
	Distance    	2.5291e+06  # [ly]
	Radius      	     88.71  # [ly]
	CoreRadius  	    0.0041  # [arcmin]
	KingConcentration     1.47  # c = log10(r_t/r_c)
	AbsMag      	    -7.648  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+211"
}

Globular "Bol 212:SKHB 263"
{
	RA          	  0.734186  # [hours]
	Dec         	  41.08231  # [degrees]
	Distance    	2.5197e+06  # [ly]
	Radius      	     117.7  # [ly]
	CoreRadius  	    0.0035  # [arcmin]
	KingConcentration     1.66  # c = log10(r_t/r_c)
	AbsMag      	     -9.05  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+212"
}

Globular "2E 165:Bol 213:SKHB 264"
{
	RA          	  0.734309  # [hours]
	Dec         	  41.51075  # [degrees]
	Distance    	 2.637e+06  # [ly]
	Radius      	     51.21  # [ly]
	CoreRadius  	    0.0022  # [arcmin]
	KingConcentration     1.49  # c = log10(r_t/r_c)
	AbsMag      	    -7.708  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=2E+165"
}

Globular "Bol 215:SKHB 266"
{
	RA          	  0.735109  # [hours]
	Dec         	  41.52883  # [degrees]
	Distance    	2.6245e+06  # [ly]
	Radius      	     86.11  # [ly]
	CoreRadius  	    0.0032  # [arcmin]
	KingConcentration     1.55  # c = log10(r_t/r_c)
	AbsMag      	    -7.298  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+215"
}

Globular "[KLG2007] GC1 83"
{
	RA          	  0.736108  # [hours]
	Dec         	  41.85794  # [degrees]
	Distance    	2.6201e+06  # [ly]
	Radius      	     65.23  # [ly]
	CoreRadius  	    0.0004  # [arcmin]
	KingConcentration     2.34  # c = log10(r_t/r_c)
	AbsMag      	    -8.104  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=%5BKLG2007%5D+GC1+83"
}

Globular "Bol 217:SKHB 269"
{
	RA          	  0.736278  # [hours]
	Dec         	  41.39753  # [degrees]
	Distance    	2.5461e+06  # [ly]
	Radius      	     61.64  # [ly]
	CoreRadius  	    0.0062  # [arcmin]
	KingConcentration     1.13  # c = log10(r_t/r_c)
	AbsMag      	    -7.942  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+217"
}

Globular "Bol 218:SKHB 272"
{
	RA          	  0.737311  # [hours]
	Dec         	  41.32206  # [degrees]
	Distance    	2.6032e+06  # [ly]
	Radius      	     131.1  # [ly]
	CoreRadius  	    0.0019  # [arcmin]
	KingConcentration     1.96  # c = log10(r_t/r_c)
	AbsMag      	     -9.75  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+218"
}

Globular "Bol 363:SKHB 274"
{
	RA          	  0.738119  # [hours]
	Dec         	  40.55972  # [degrees]
	Distance    	2.5664e+06  # [ly]
	Radius      	     27.72  # [ly]
	CoreRadius  	    0.0091  # [arcmin]
	KingConcentration     0.61  # c = log10(r_t/r_c)
	AbsMag      	    -6.623  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+363"
}

Globular "Bol 220:SKHB 275"
{
	RA          	  0.738733  # [hours]
	Dec         	  41.50969  # [degrees]
	Distance    	2.5889e+06  # [ly]
	Radius      	     119.4  # [ly]
	CoreRadius  	    0.0089  # [arcmin]
	KingConcentration     1.25  # c = log10(r_t/r_c)
	AbsMag      	    -7.988  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+220"
}

Globular "Bol 222:SKHB 277"
{
	RA          	  0.740375  # [hours]
	Dec         	  41.23664  # [degrees]
	Distance    	2.5389e+06  # [ly]
	Radius      	     8.006  # [ly]
	CoreRadius  	    0.0108  # [arcmin]
	KingConcentration     1.44  # c = log10(r_t/r_c)
	AbsMag      	    -7.026  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+222"
}

Globular "[KLG2007] GC1 86"
{
	RA          	  0.740575  # [hours]
	Dec         	  41.58733  # [degrees]
	Distance    	  2.64e+06  # [ly]
	Radius      	     112.5  # [ly]
	CoreRadius  	    0.0134  # [arcmin]
	KingConcentration     1.04  # c = log10(r_t/r_c)
	AbsMag      	    -5.661  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=%5BKLG2007%5D+GC1+86"
}

Globular "BA 3-1:Bol 224:SKHB 279"
{
	RA          	  0.740859  # [hours]
	Dec         	   41.4805  # [degrees]
	Distance    	2.5966e+06  # [ly]
	Radius      	     141.6  # [ly]
	CoreRadius  	    0.0225  # [arcmin]
	KingConcentration     0.92  # c = log10(r_t/r_c)
	AbsMag      	    -9.195  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=BA+3-1"
}

Globular "Bol 279"
{
	RA          	  0.741114  # [hours]
	Dec         	  41.73622  # [degrees]
	Distance    	2.6052e+06  # [ly]
	Radius      	     211.3  # [ly]
	CoreRadius  	    0.0044  # [arcmin]
	KingConcentration      1.8  # c = log10(r_t/r_c)
	AbsMag      	    -5.912  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+279"
}

Globular "2E 166:Bol 225:SKHB 280"
{
	RA          	  0.741523  # [hours]
	Dec         	 41.359878  # [degrees]
	Distance    	2.5586e+06  # [ly]
	Radius      	     82.19  # [ly]
	CoreRadius  	    0.0029  # [arcmin]
	KingConcentration     1.58  # c = log10(r_t/r_c)
	AbsMag      	   -10.253  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=2E+166"
}

Globular "Bol 228:SKHB 281"
{
	RA          	  0.742561  # [hours]
	Dec         	  41.69108  # [degrees]
	Distance    	2.5478e+06  # [ly]
	Radius      	     48.27  # [ly]
	CoreRadius  	    0.0119  # [arcmin]
	KingConcentration     0.74  # c = log10(r_t/r_c)
	AbsMag      	    -7.674  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+228"
}

Globular "Bol 229:SKHB 282"
{
	RA          	  0.742722  # [hours]
	Dec         	  41.64128  # [degrees]
	Distance    	2.6385e+06  # [ly]
	Radius      	     128.2  # [ly]
	CoreRadius  	    0.0265  # [arcmin]
	KingConcentration      0.8  # c = log10(r_t/r_c)
	AbsMag      	     -7.37  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+229"
}

Globular "Bol 230:SKHB 283"
{
	RA          	  0.743105  # [hours]
	Dec         	  40.95342  # [degrees]
	Distance    	2.5421e+06  # [ly]
	Radius      	     87.41  # [ly]
	CoreRadius  	    0.0019  # [arcmin]
	KingConcentration      1.8  # c = log10(r_t/r_c)
	AbsMag      	    -8.409  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+230"
}

Globular "BA 3-27:Bol 365:SKHB 284"
{
	RA          	  0.743455  # [hours]
	Dec         	  42.28903  # [degrees]
	Distance    	2.5304e+06  # [ly]
	Radius      	     122.6  # [ly]
	CoreRadius  	    0.0078  # [arcmin]
	KingConcentration     1.33  # c = log10(r_t/r_c)
	AbsMag      	    -7.559  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=BA+3-27"
}

Globular "Bol 231:SKHB 285"
{
	RA          	  0.744053  # [hours]
	Dec         	  41.46303  # [degrees]
	Distance    	2.5636e+06  # [ly]
	Radius      	     73.06  # [ly]
	CoreRadius  	    0.0028  # [arcmin]
	KingConcentration     1.54  # c = log10(r_t/r_c)
	AbsMag      	    -7.217  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+231"
}

Globular "Bol 232:SKHB 286"
{
	RA          	  0.744508  # [hours]
	Dec         	  41.25011  # [degrees]
	Distance    	2.6244e+06  # [ly]
	Radius      	     99.48  # [ly]
	CoreRadius  	    0.0027  # [arcmin]
	KingConcentration     1.69  # c = log10(r_t/r_c)
	AbsMag      	    -8.908  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+232"
}

Globular "Bol 233:SKHB 287"
{
	RA          	  0.745033  # [hours]
	Dec         	  41.73181  # [degrees]
	Distance    	2.5248e+06  # [ly]
	Radius      	     89.69  # [ly]
	CoreRadius  	    0.0048  # [arcmin]
	KingConcentration     1.41  # c = log10(r_t/r_c)
	AbsMag      	    -8.614  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+233"
}

Globular "Bol 281:SKHB 288"
{
	RA          	  0.745239  # [hours]
	Dec         	  41.33569  # [degrees]
	Distance    	2.5528e+06  # [ly]
	Radius      	     44.68  # [ly]
	CoreRadius  	    0.0174  # [arcmin]
	KingConcentration     0.54  # c = log10(r_t/r_c)
	AbsMag      	    -6.798  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+281"
}

Globular "BA 3-24:Bol 366:SKHB 291"
{
	RA          	    0.7463  # [hours]
	Dec         	    42.064  # [degrees]
	Distance    	2.5493e+06  # [ly]
	Radius      	     80.89  # [ly]
	CoreRadius  	    0.0151  # [arcmin]
	KingConcentration     0.86  # c = log10(r_t/r_c)
	AbsMag      	    -7.985  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=BA+3-24"
}

Globular "Bol 368:SKHB 293"
{
	RA          	  0.746611  # [hours]
	Dec         	  41.85253  # [degrees]
	Distance    	2.5551e+06  # [ly]
	Radius      	     0.056  # [ly]
	CoreRadius  	    0.0001  # [arcmin]
	KingConcentration    3.735  # c = log10(r_t/r_c)
	AbsMag      	     -6.42  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+368"
}

Globular "Bol D255"
{
	RA          	  0.746822  # [hours]
	Dec         	  42.10369  # [degrees]
	Distance    	2.5339e+06  # [ly]
	Radius      	     115.1  # [ly]
	CoreRadius  	    0.0291  # [arcmin]
	KingConcentration     0.73  # c = log10(r_t/r_c)
	AbsMag      	    -5.482  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+D255"
}

Globular "Bol 283:SKHB 296"
{
	RA          	  0.748722  # [hours]
	Dec         	  41.28333  # [degrees]
	Distance    	2.5111e+06  # [ly]
	Radius      	        91  # [ly]
	CoreRadius  	    0.0086  # [arcmin]
	KingConcentration     1.16  # c = log10(r_t/r_c)
	AbsMag      	    -6.422  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+283"
}

Globular "Bol 236:SKHB 298"
{
	RA          	  0.752475  # [hours]
	Dec         	  40.84133  # [degrees]
	Distance    	2.5633e+06  # [ly]
	Radius      	     35.55  # [ly]
	CoreRadius  	    0.0123  # [arcmin]
	KingConcentration     0.59  # c = log10(r_t/r_c)
	AbsMag      	    -7.097  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+236"
}

Globular "Bol 237:SKHB 299"
{
	RA          	  0.752567  # [hours]
	Dec         	  41.37625  # [degrees]
	Distance    	2.5428e+06  # [ly]
	Radius      	     235.5  # [ly]
	CoreRadius  	    0.0062  # [arcmin]
	KingConcentration     1.71  # c = log10(r_t/r_c)
	AbsMag      	    -7.149  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+237"
}

Globular "Bol 238:SKHB 301"
{
	RA          	  0.754081  # [hours]
	Dec         	  41.32694  # [degrees]
	Distance    	2.5677e+06  # [ly]
	Radius      	     139.3  # [ly]
	CoreRadius  	    0.0043  # [arcmin]
	KingConcentration     1.64  # c = log10(r_t/r_c)
	AbsMag      	    -8.071  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+238"
}

Globular "Bol 239"
{
	RA          	  0.754333  # [hours]
	Dec         	  41.58808  # [degrees]
	Distance    	2.5442e+06  # [ly]
	Radius      	     91.32  # [ly]
	CoreRadius  	    0.0017  # [arcmin]
	KingConcentration     1.86  # c = log10(r_t/r_c)
	AbsMag      	    -7.271  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+239"
}

Globular "Bol 240:SKHB 302"
{
	RA          	  0.756958  # [hours]
	Dec         	  41.10617  # [degrees]
	Distance    	2.5725e+06  # [ly]
	Radius      	     125.6  # [ly]
	CoreRadius  	    0.0028  # [arcmin]
	KingConcentration     1.78  # c = log10(r_t/r_c)
	AbsMag      	    -9.275  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+240"
}

Globular "BA 3-2:Bol 373:SKHB 305"
{
	RA          	  0.761625  # [hours]
	Dec         	  41.75928  # [degrees]
	Distance    	 2.619e+06  # [ly]
	Radius      	      78.6  # [ly]
	CoreRadius  	    0.0021  # [arcmin]
	KingConcentration     1.69  # c = log10(r_t/r_c)
	AbsMag      	    -8.824  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=BA+3-2"
}

Globular "[KLG2007] GC1 104"
{
	RA          	  0.762309  # [hours]
	Dec         	  41.95772  # [degrees]
	Distance    	2.5432e+06  # [ly]
	Radius      	     50.23  # [ly]
	CoreRadius  	    0.0031  # [arcmin]
	KingConcentration     1.34  # c = log10(r_t/r_c)
	AbsMag      	     -7.72  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=%5BKLG2007%5D+GC1+104"
}

Globular "BA 1-202"
{
	RA          	  0.762417  # [hours]
	Dec         	  41.86658  # [degrees]
	Distance    	2.5484e+06  # [ly]
	Radius      	     56.75  # [ly]
	CoreRadius  	    0.0065  # [arcmin]
	KingConcentration     1.07  # c = log10(r_t/r_c)
	AbsMag      	    -7.414  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=BA+1-202"
}

Globular "2E 169:Bol 375:SKHB 307"
{
	RA          	   0.76266  # [hours]
	Dec         	 41.661736  # [degrees]
	Distance    	2.5889e+06  # [ly]
	Radius      	     173.5  # [ly]
	CoreRadius  	    0.0012  # [arcmin]
	KingConcentration     2.27  # c = log10(r_t/r_c)
	AbsMag      	    -6.988  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=2E+169"
}

Globular "Bol 376:SKHB 309"
{
	RA          	  0.763441  # [hours]
	Dec         	  41.71108  # [degrees]
	Distance    	2.5977e+06  # [ly]
	Radius      	     8.442  # [ly]
	CoreRadius  	    0.0112  # [arcmin]
	KingConcentration    1.727  # c = log10(r_t/r_c)
	AbsMag      	    -6.446  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+376"
}

Globular "BA 3-5:Bol 378:SKHB 311"
{
	RA          	    0.7659  # [hours]
	Dec         	  41.89189  # [degrees]
	Distance    	2.5914e+06  # [ly]
	Radius      	     129.2  # [ly]
	CoreRadius  	     0.003  # [arcmin]
	KingConcentration     1.75  # c = log10(r_t/r_c)
	AbsMag      	    -6.941  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=BA+3-5"
}

Globular "Bol 382:SKHB 317"
{
	RA          	  0.769541  # [hours]
	Dec         	  41.62789  # [degrees]
	Distance    	2.5368e+06  # [ly]
	Radius      	     50.23  # [ly]
	CoreRadius  	    0.0057  # [arcmin]
	KingConcentration     1.08  # c = log10(r_t/r_c)
	AbsMag      	    -7.094  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+382"
}

Globular "BA 3-8:Bol 386:SKHB 322"
{
	RA          	  0.774171  # [hours]
	Dec         	  42.03131  # [degrees]
	Distance    	2.5871e+06  # [ly]
	Radius      	     96.22  # [ly]
	CoreRadius  	    0.0021  # [arcmin]
	KingConcentration     1.78  # c = log10(r_t/r_c)
	AbsMag      	    -8.807  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=BA+3-8"
}

Globular "Bol 391:SKHB 328"
{
	RA          	  0.782803  # [hours]
	Dec         	  41.56578  # [degrees]
	Distance    	2.5647e+06  # [ly]
	Radius      	     65.88  # [ly]
	CoreRadius  	    0.0073  # [arcmin]
	KingConcentration     1.08  # c = log10(r_t/r_c)
	AbsMag      	    -7.972  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+391"
}

Globular "[KLG2007] GC1 109"
{
	RA          	  0.788014  # [hours]
	Dec         	  41.05325  # [degrees]
	Distance    	2.5231e+06  # [ly]
	Radius      	     186.6  # [ly]
	CoreRadius  	    0.0035  # [arcmin]
	KingConcentration     1.86  # c = log10(r_t/r_c)
	AbsMag      	    -7.003  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=%5BKLG2007%5D+GC1+109"
}

Globular "Bol 397:SKHB 336"
{
	RA          	    0.7909  # [hours]
	Dec         	  41.20289  # [degrees]
	Distance    	2.5744e+06  # [ly]
	Radius      	     91.65  # [ly]
	CoreRadius  	    0.0021  # [arcmin]
	KingConcentration     1.77  # c = log10(r_t/r_c)
	AbsMag      	    -7.956  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+397"
}

Globular "Bol 398:SKHB 341"
{
	RA          	  0.799383  # [hours]
	Dec         	  41.81264  # [degrees]
	Distance    	2.5953e+06  # [ly]
	Radius      	     71.43  # [ly]
	CoreRadius  	    0.0086  # [arcmin]
	KingConcentration     1.04  # c = log10(r_t/r_c)
	AbsMag      	    -7.042  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+398"
}

Globular "Bol 399:SKHB 342"
{
	RA          	  0.799875  # [hours]
	Dec         	  41.59125  # [degrees]
	Distance    	2.5905e+06  # [ly]
	Radius      	       151  # [ly]
	CoreRadius  	    0.0041  # [arcmin]
	KingConcentration     1.69  # c = log10(r_t/r_c)
	AbsMag      	    -7.222  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+399"
}

Globular "BA 3-9:Bol 400:SKHB 343"
{
	RA          	    0.8004  # [hours]
	Dec         	  42.42583  # [degrees]
	Distance    	2.5676e+06  # [ly]
	Radius      	     84.15  # [ly]
	CoreRadius  	    0.0017  # [arcmin]
	KingConcentration     1.83  # c = log10(r_t/r_c)
	AbsMag      	     -7.98  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=BA+3-9"
}

Globular "Bol 401:SKHB 344"
{
	RA          	  0.802364  # [hours]
	Dec         	  41.67831  # [degrees]
	Distance    	2.5252e+06  # [ly]
	Radius      	     142.5  # [ly]
	CoreRadius  	    0.0027  # [arcmin]
	KingConcentration     1.85  # c = log10(r_t/r_c)
	AbsMag      	    -7.618  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+401"
}

Globular "Bol 405:SKHB 351"
{
	RA          	  0.827722  # [hours]
	Dec         	  41.59161  # [degrees]
	Distance    	2.5862e+06  # [ly]
	Radius      	     135.4  # [ly]
	CoreRadius  	    0.0064  # [arcmin]
	KingConcentration     1.45  # c = log10(r_t/r_c)
	AbsMag      	    -9.301  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Bol+405"
}

Globular "Mayall V:Bol 407:SKHB 352"
{
	RA          	    0.8361  # [hours]
	Dec         	  41.68367  # [degrees]
	Distance    	2.5629e+06  # [ly]
	Radius      	     88.39  # [ly]
	CoreRadius  	    0.0038  # [arcmin]
	KingConcentration     1.49  # c = log10(r_t/r_c)
	AbsMag      	    -8.424  # [V mags]
	Axis        [ -0.7429  -0.2364  -0.6263]
	Angle       	     175.9  # [degrees]
	InfoURL  "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NAME+Mayall+V"
}